@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::PluginBundle::ARJONES;
 {
-  $Dist::Zilla::PluginBundle::ARJONES::VERSION = '1.120460';
+  $Dist::Zilla::PluginBundle::ARJONES::VERSION = '1.120570';
 }
 
 # ABSTRACT: L<Dist::Zilla> plugins for ARJONES
@@ -22,7 +22,6 @@ use Dist::Zilla::Plugin::Clean;
 use Dist::Zilla::Plugin::NoTabsTests;
 use Dist::Zilla::Plugin::Test::Kwalitee;
 use Dist::Zilla::Plugin::Test::Pod::No404s;
-use Dist::Zilla::Plugin::Test::PodSpelling;
 use Dist::Zilla::Plugin::Test::Portability;
 use Dist::Zilla::Plugin::NoSmartCommentsTests;
 
@@ -87,11 +86,6 @@ sub configure {
         }
     }
 
-    # our stopwords
-    $self->push_stopwords(qw/ARJONES ARJONES's TODO/);
-    $self->add_plugins(
-        [ 'Test::PodSpelling' => { stopwords => [ $self->uniq_stopwords ] } ] );
-
     $self->add_plugins( [ PodWeaver => { config_plugin => '@ARJONES' } ] );
 
     $self->add_plugins( [ GithubMeta => { issues => 1, } ], );
@@ -117,7 +111,7 @@ Dist::Zilla::PluginBundle::ARJONES - L<Dist::Zilla> plugins for ARJONES
 
 =head1 VERSION
 
-version 1.120460
+version 1.120570
 
 =for stopwords Prereqs CPAN
 =head1 DESCRIPTION
@@ -133,7 +127,6 @@ This is the plugin bundle that ARJONES uses. It is equivalent to:
   [Test::Portability]
   [Test::Kwalitee]
   [Test::Pod::No404s]
-  [Test::PodSpelling]
   [NoSmartCommentsTests]
 
   [AutoPrereqs]
